@@ -34,8 +34,8 @@
 
 
 AbstractGroupItem::AbstractGroupItem(double /* fps */) :
-        QObject(),
-        QGraphicsItemGroup()
+    QObject(),
+    QGraphicsItemGroup()
 {
     setZValue(1);
     setFlags(QGraphicsItem::ItemIsMovable | QGraphicsItem::ItemIsSelectable);
@@ -48,7 +48,7 @@ AbstractGroupItem::AbstractGroupItem(double /* fps */) :
 
 int AbstractGroupItem::type() const
 {
-    return GROUPWIDGET;
+    return GroupWidget;
 }
 
 int AbstractGroupItem::track() const
@@ -57,14 +57,14 @@ int AbstractGroupItem::track() const
     int topTrack = -1;
     QList<QGraphicsItem *> children = childItems();
     for (int i = 0; i < children.count(); ++i) {
-	if (children.at(i)->type() == GROUPWIDGET) {
-	    children.append(children.at(i)->childItems());
-	    continue;
-	}
+        if (children.at(i)->type() == GroupWidget) {
+            children.append(children.at(i)->childItems());
+            continue;
+        }
         AbstractClipItem *item = static_cast <AbstractClipItem *>(children.at(i));
         if (item && (topTrack == -1 || topTrack > item->track())) {
-	    topTrack = item->track();
-	}
+            topTrack = item->track();
+        }
     }
     return topTrack;
 }
@@ -78,7 +78,7 @@ void AbstractGroupItem::setItemLocked(bool locked)
     setFlag(QGraphicsItem::ItemIsSelectable, !locked);
 
     foreach (QGraphicsItem *child, childItems())
-        ((AbstractClipItem *)child)->setItemLocked(locked);
+        static_cast<AbstractClipItem*>(child)->setItemLocked(locked);
 }
 
 bool AbstractGroupItem::isItemLocked() const
@@ -92,31 +92,31 @@ CustomTrackScene* AbstractGroupItem::projectScene()
     return NULL;
 }
 
-QPainterPath AbstractGroupItem::clipGroupSpacerShape(QPointF offset) const
+QPainterPath AbstractGroupItem::clipGroupSpacerShape(const QPointF &offset) const
 {
-    return spacerGroupShape(AVWIDGET, offset);
+    return spacerGroupShape(AVWidget, offset);
 }
 
-QPainterPath AbstractGroupItem::clipGroupShape(QPointF offset) const
+QPainterPath AbstractGroupItem::clipGroupShape(const QPointF &offset) const
 {
-    return groupShape(AVWIDGET, offset);
+    return groupShape(AVWidget, offset);
 }
 
-QPainterPath AbstractGroupItem::transitionGroupShape(QPointF offset) const
+QPainterPath AbstractGroupItem::transitionGroupShape(const QPointF &offset) const
 {
-    return groupShape(TRANSITIONWIDGET, offset);
+    return groupShape(TransitionWidget, offset);
 }
 
-QPainterPath AbstractGroupItem::groupShape(GRAPHICSRECTITEM type, QPointF offset) const
+QPainterPath AbstractGroupItem::groupShape(GraphicsRectItem type, const QPointF &offset) const
 {
     QPainterPath path;
     QList<QGraphicsItem *> children = childItems();
-    for (int i = 0; i < children.count(); i++) {
+    for (int i = 0; i < children.count(); ++i) {
         if (children.at(i)->type() == (int)type) {
             QRectF r(children.at(i)->sceneBoundingRect());
             r.translate(offset);
             path.addRect(r);
-        } else if (children.at(i)->type() == GROUPWIDGET) {
+        } else if (children.at(i)->type() == GroupWidget) {
             QList<QGraphicsItem *> subchildren = children.at(i)->childItems();
             for (int j = 0; j < subchildren.count(); j++) {
                 if (subchildren.at(j)->type() == (int)type) {
@@ -130,23 +130,23 @@ QPainterPath AbstractGroupItem::groupShape(GRAPHICSRECTITEM type, QPointF offset
     return path;
 }
 
-QPainterPath AbstractGroupItem::spacerGroupShape(GRAPHICSRECTITEM type, QPointF offset) const
+QPainterPath AbstractGroupItem::spacerGroupShape(GraphicsRectItem type, const QPointF &offset) const
 {
     QPainterPath path;
     QList<QGraphicsItem *> children = childItems();
-    for (int i = 0; i < children.count(); i++) {
+    for (int i = 0; i < children.count(); ++i) {
         if (children.at(i)->type() == (int)type) {
             QRectF r(children.at(i)->sceneBoundingRect());
             r.translate(offset);
-	    r.setRight(scene()->width());
+            r.setRight(scene()->width());
             path.addRect(r);
-        } else if (children.at(i)->type() == GROUPWIDGET) {
+        } else if (children.at(i)->type() == GroupWidget) {
             QList<QGraphicsItem *> subchildren = children.at(i)->childItems();
             for (int j = 0; j < subchildren.count(); j++) {
                 if (subchildren.at(j)->type() == (int)type) {
                     QRectF r(subchildren.at(j)->sceneBoundingRect());
                     r.translate(offset);
-		    r.setRight(scene()->width());
+                    r.setRight(scene()->width());
                     path.addRect(r);
                 }
             }
@@ -212,42 +212,42 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
         int xpos = projectScene()->getSnapPointForPos((int)(start.x() + newPos.x() - pos().x()), KdenliveSettings::snaptopoints());
 
         xpos = qMax(xpos, 0);
-        //kDebug()<<"GRP XPOS:"<<xpos<<", START:"<<start.x()<<",NEW:"<<newPos.x()<<"; SCENE:"<<scenePos().x()<<",POS:"<<pos().x();
+        //kDebug()<<"GRP XPOS:"<<xpos<<", START:"<<start.x()<<",NEW:"<<newPos.x()<<"; SCENE:"<<scenePos().x()<<",POS:"<<pos().x();
         newPos.setX((int)(pos().x() + xpos - (int) start.x()));
-	QStringList lockedTracks = property("locked_tracks").toStringList();
+        QStringList lockedTracks = property("locked_tracks").toStringList();
         int proposedTrack = (property("y_absolute").toInt() + newPos.y()) / trackHeight;
         // Check if top item is a clip or a transition
         int offset = 0;
         int topTrack = -1;
-	QList<int> groupTracks;
+        QList<int> groupTracks;
         QList<QGraphicsItem *> children = childItems();
-        for (int i = 0; i < children.count(); i++) {
+        for (int i = 0; i < children.count(); ++i) {
             int currentTrack = 0;
-	    if (children.at(i)->type() == AVWIDGET || children.at(i)->type() == TRANSITIONWIDGET) {
-		currentTrack = static_cast <AbstractClipItem*> (children.at(i))->track();
-		if (!groupTracks.contains(currentTrack)) groupTracks.append(currentTrack);
-	    }
-	    else if (children.at(i)->type() == GROUPWIDGET) {
-		currentTrack = static_cast <AbstractGroupItem*> (children.at(i))->track();
-	    }
-	    else continue;
-            if (children.at(i)->type() == AVWIDGET) {
+            if (children.at(i)->type() == AVWidget || children.at(i)->type() == TransitionWidget) {
+                currentTrack = static_cast <AbstractClipItem*> (children.at(i))->track();
+                if (!groupTracks.contains(currentTrack)) groupTracks.append(currentTrack);
+            }
+            else if (children.at(i)->type() == GroupWidget) {
+                currentTrack = static_cast <AbstractGroupItem*> (children.at(i))->track();
+            }
+            else continue;
+            if (children.at(i)->type() == AVWidget) {
                 if (topTrack == -1 || currentTrack <= topTrack) {
                     offset = 0;
                     topTrack = currentTrack;
                 }
-            } else if (children.at(i)->type() == TRANSITIONWIDGET) {
+            } else if (children.at(i)->type() == TransitionWidget) {
                 if (topTrack == -1 || currentTrack < topTrack) {
                     offset = (int)(trackHeight / 3 * 2 - 1);
                     topTrack = currentTrack;
                 }
-            } else if (children.at(i)->type() == GROUPWIDGET) {
+            } else if (children.at(i)->type() == GroupWidget) {
                 QList<QGraphicsItem *> subchildren = children.at(i)->childItems();
                 bool clipGroup = false;
                 for (int j = 0; j < subchildren.count(); j++) {
-                    if (subchildren.at(j)->type() == AVWIDGET || subchildren.at(j)->type() == TRANSITIONWIDGET) {
-			int subTrack = static_cast <AbstractClipItem*> (subchildren.at(j))->track();
-			if (!groupTracks.contains(subTrack)) groupTracks.append(subTrack);
+                    if (subchildren.at(j)->type() == AVWidget || subchildren.at(j)->type() == TransitionWidget) {
+                        int subTrack = static_cast <AbstractClipItem*> (subchildren.at(j))->track();
+                        if (!groupTracks.contains(subTrack)) groupTracks.append(subTrack);
                         clipGroup = true;
                     }
                 }
@@ -266,22 +266,22 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
         }
         // Check no clip in the group goes outside of existing tracks
         int maximumTrack = projectScene()->tracksCount() - 1;
-	int groupHeight = 0;
-	for (int i = 0; i < groupTracks.count(); i++) {
-	    int offset = groupTracks.at(i) - topTrack;
-	    if (offset > groupHeight) groupHeight = offset; 
-	}
-	maximumTrack -= groupHeight;
+        int groupHeight = 0;
+        for (int i = 0; i < groupTracks.count(); ++i) {
+            int offset = groupTracks.at(i) - topTrack;
+            if (offset > groupHeight) groupHeight = offset;
+        }
+        maximumTrack -= groupHeight;
         proposedTrack = qMin(proposedTrack, maximumTrack);
         proposedTrack = qMax(proposedTrack, 0);
-	int groupOffset = proposedTrack - topTrack;
-	if (!lockedTracks.isEmpty()) {
-	    for (int i = 0; i < groupTracks.count(); i++) {
-		if (lockedTracks.contains(QString::number(groupTracks.at(i) + groupOffset))) {
-		    return pos();
-		}
-	    }
-	}
+        int groupOffset = proposedTrack - topTrack;
+        if (!lockedTracks.isEmpty()) {
+            for (int i = 0; i < groupTracks.count(); ++i) {
+                if (lockedTracks.contains(QString::number(groupTracks.at(i) + groupOffset))) {
+                    return pos();
+                }
+            }
+        }
         newPos.setY((int)((proposedTrack) * trackHeight) + offset);
         //if (newPos == start) return start;
 
@@ -292,12 +292,12 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
 
         QList<QGraphicsItem*> collidingItems;
         QPainterPath shape;
-        if (projectScene()->editMode() == NORMALEDIT) {
+        if (projectScene()->editMode() == NormalEdit) {
             shape = clipGroupShape(newPos - pos());
             collidingItems = scene()->items(shape, Qt::IntersectsItemShape);
             collidingItems.removeAll(this);
-            for (int i = 0; i < children.count(); i++) {
-                if (children.at(i)->type() == GROUPWIDGET) {
+            for (int i = 0; i < children.count(); ++i) {
+                if (children.at(i)->type() == GroupWidget) {
                     QList<QGraphicsItem *> subchildren = children.at(i)->childItems();
                     for (int j = 0; j < subchildren.count(); j++) {
                         collidingItems.removeAll(subchildren.at(j));
@@ -309,28 +309,20 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
         if (!collidingItems.isEmpty()) {
             bool forwardMove = xpos > start.x();
             int offset = 0;
-            for (int i = 0; i < collidingItems.count(); i++) {
+            for (int i = 0; i < collidingItems.count(); ++i) {
                 QGraphicsItem *collision = collidingItems.at(i);
-                if (collision->type() == AVWIDGET) {
+                if (collision->type() == AVWidget) {
                     // Collision
                     if (newPos.y() != pos().y()) {
                         // Track change results in collision, restore original position
                         return pos();
                     }
                     AbstractClipItem *item = static_cast <AbstractClipItem *>(collision);
-                    if (forwardMove) {
-                        // Moving forward, determine best pos
-                        QPainterPath clipPath;
-                        clipPath.addRect(item->sceneBoundingRect());
-                        QPainterPath res = shape.intersected(clipPath);
-                        offset = qMax(offset, (int)(res.boundingRect().width() + 0.5));
-                    } else {
-                        // Moving backward, determine best pos
-                        QPainterPath clipPath;
-                        clipPath.addRect(item->sceneBoundingRect());
-                        QPainterPath res = shape.intersected(clipPath);
-                        offset = qMax(offset, (int)(res.boundingRect().width() + 0.5));
-                    }
+                    // Determine best pos
+                    QPainterPath clipPath;
+                    clipPath.addRect(item->sceneBoundingRect());
+                    QPainterPath res = shape.intersected(clipPath);
+                    offset = qMax(offset, (int)(res.boundingRect().width() + 0.5));
                 }
             }
             if (offset > 0) {
@@ -342,8 +334,8 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
                 // If there is still a collision after our position adjust, restore original pos
                 collidingItems = scene()->items(clipGroupShape(newPos - pos()), Qt::IntersectsItemShape);
                 collidingItems.removeAll(this);
-                for (int i = 0; i < children.count(); i++) {
-                    if (children.at(i)->type() == GROUPWIDGET) {
+                for (int i = 0; i < children.count(); ++i) {
+                    if (children.at(i)->type() == GroupWidget) {
                         QList<QGraphicsItem *> subchildren = children.at(i)->childItems();
                         for (int j = 0; j < subchildren.count(); j++) {
                             collidingItems.removeAll(subchildren.at(j));
@@ -351,17 +343,17 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
                     }
                     collidingItems.removeAll(children.at(i));
                 }
-                for (int i = 0; i < collidingItems.count(); i++)
-                    if (collidingItems.at(i)->type() == AVWIDGET) return pos();
+                for (int i = 0; i < collidingItems.count(); ++i)
+                    if (collidingItems.at(i)->type() == AVWidget) return pos();
             }
         }
 
-        if (projectScene()->editMode() == NORMALEDIT) {
+        if (projectScene()->editMode() == NormalEdit) {
             shape = transitionGroupShape(newPos - pos());
             collidingItems = scene()->items(shape, Qt::IntersectsItemShape);
             collidingItems.removeAll(this);
-            for (int i = 0; i < children.count(); i++) {
-                if (children.at(i)->type() == GROUPWIDGET) {
+            for (int i = 0; i < children.count(); ++i) {
+                if (children.at(i)->type() == GroupWidget) {
                     QList<QGraphicsItem *> subchildren = children.at(i)->childItems();
                     for (int j = 0; j < subchildren.count(); j++) {
                         collidingItems.removeAll(subchildren.at(j));
@@ -374,28 +366,20 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
         else {
             bool forwardMove = xpos > start.x();
             int offset = 0;
-            for (int i = 0; i < collidingItems.count(); i++) {
+            for (int i = 0; i < collidingItems.count(); ++i) {
                 QGraphicsItem *collision = collidingItems.at(i);
-                if (collision->type() == TRANSITIONWIDGET) {
+                if (collision->type() == TransitionWidget) {
                     // Collision
                     if (newPos.y() != pos().y()) {
                         // Track change results in collision, restore original position
                         return pos();
                     }
                     AbstractClipItem *item = static_cast <AbstractClipItem *>(collision);
-                    if (forwardMove) {
-                        // Moving forward, determine best pos
-                        QPainterPath clipPath;
-                        clipPath.addRect(item->sceneBoundingRect());
-                        QPainterPath res = shape.intersected(clipPath);
-                        offset = qMax(offset, (int)(res.boundingRect().width() + 0.5));
-                    } else {
-                        // Moving backward, determine best pos
-                        QPainterPath clipPath;
-                        clipPath.addRect(item->sceneBoundingRect());
-                        QPainterPath res = shape.intersected(clipPath);
-                        offset = qMax(offset, (int)(res.boundingRect().width() + 0.5));
-                    }
+                    // Determine best pos
+		    QPainterPath clipPath;
+		    clipPath.addRect(item->sceneBoundingRect());
+		    QPainterPath res = shape.intersected(clipPath);
+		    offset = qMax(offset, (int)(res.boundingRect().width() + 0.5));
                 }
             }
             if (offset > 0) {
@@ -406,11 +390,11 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
                 }
                 // If there is still a collision after our position adjust, restore original pos
                 collidingItems = scene()->items(transitionGroupShape(newPos - pos()), Qt::IntersectsItemShape);
-                for (int i = 0; i < children.count(); i++) {
+                for (int i = 0; i < children.count(); ++i) {
                     collidingItems.removeAll(children.at(i));
                 }
-                for (int i = 0; i < collidingItems.count(); i++)
-                    if (collidingItems.at(i)->type() == TRANSITIONWIDGET) return pos();
+                for (int i = 0; i < collidingItems.count(); ++i)
+                    if (collidingItems.at(i)->type() == TransitionWidget) return pos();
             }
         }
         return newPos;
@@ -426,16 +410,16 @@ void AbstractGroupItem::dropEvent(QGraphicsSceneDragDropEvent * event)
     doc.setContent(effects, true);
     QDomElement e = doc.documentElement();
     e.setAttribute("kdenlive_ix", 0);
-    CustomTrackView *view = (CustomTrackView *) scene()->views()[0];
+    CustomTrackView *view = static_cast<CustomTrackView*>(scene()->views()[0]);
     QPointF dropPos = event->scenePos();
     QList<QGraphicsItem *> selection = scene()->items(dropPos);
     AbstractClipItem *dropChild = NULL;
-    for (int i = 0; i < selection.count(); i++) {
-	if (selection.at(i)->type() == AVWIDGET) {
-            dropChild = (AbstractClipItem *) selection.at(i);
-	    break;
+    for (int i = 0; i < selection.count(); ++i) {
+        if (selection.at(i)->type() == AVWidget) {
+            dropChild = static_cast<AbstractClipItem*>(selection.at(i));
+            break;
         }
-    }           
+    }
     if (view) view->slotAddGroupEffect(e, this, dropChild);
 }
 
@@ -457,15 +441,15 @@ void AbstractGroupItem::mousePressEvent(QGraphicsSceneMouseEvent * event)
         // User want to do a rectangle selection, so ignore the event to pass it to the view
         event->ignore();
     } else {
-	QList <QGraphicsItem *>list = scene()->items(event->scenePos());
-	// only allow group move if we click over an item in the group
-	foreach(const QGraphicsItem *item, list) {
-	    if (item->type() == TRANSITIONWIDGET || item->type() == AVWIDGET) {
-		QGraphicsItem::mousePressEvent(event);
-		return;
-	    }
-	}
-	event->ignore();
+        QList <QGraphicsItem *>list = scene()->items(event->scenePos());
+        // only allow group move if we click over an item in the group
+        foreach(const QGraphicsItem *item, list) {
+            if (item->type() == TransitionWidget || item->type() == AVWidget) {
+                QGraphicsItem::mousePressEvent(event);
+                return;
+            }
+        }
+        event->ignore();
     }
 }
 
@@ -480,7 +464,7 @@ void AbstractGroupItem::resizeStart(int diff)
     int itemcount = 0;
     for (int i = 0; i < children.count(); ++i) {
         AbstractClipItem *item = static_cast <AbstractClipItem *>(children.at(i));
-        if (item && item->type() == AVWIDGET) {
+        if (item && item->type() == AVWidget) {
             items << item;
             if (info)
                 m_resizeInfos << item->info();
@@ -507,7 +491,7 @@ void AbstractGroupItem::resizeEnd(int diff)
     int itemcount = 0;
     for (int i = 0; i < children.count(); ++i) {
         AbstractClipItem *item = static_cast <AbstractClipItem *>(children.at(i));
-        if (item && item->type() == AVWIDGET) {
+        if (item && item->type() == AVWidget) {
             items << item;
             if (info)
                 m_resizeInfos << item->info();
@@ -540,7 +524,7 @@ GenTime AbstractGroupItem::duration()
     GenTime start = GenTime(-1.0);
     GenTime end = GenTime();
     for (int i = 0; i < children.count(); ++i) {
-        if (children.at(i)->type() != GROUPWIDGET) {
+        if (children.at(i)->type() != GroupWidget) {
             AbstractClipItem *item = static_cast <AbstractClipItem *>(children.at(i));
             if (item) {
                 if (start < GenTime() || item->startPos() < start)
@@ -554,3 +538,5 @@ GenTime AbstractGroupItem::duration()
     }
     return end - start;
 }
+
+#include "abstractgroupitem.moc"
