@@ -10,13 +10,11 @@
 
 
 #include <QAction>
-#include <QColor>
 #include <QDebug>
-#include <QMouseEvent>
-#include <QMenu>
 #include <QPainter>
 
 #include <QTime>
+#include <QMenu>
 
 #include "colorplaneexport.h"
 #include "colortools.h"
@@ -24,7 +22,6 @@
 #include "colorcorrection/vectorscopegenerator.h"
 
 const float P75 = .75;
-const unsigned char DEFAULT_Y = 255;
 
 const QPointF YUV_R(-.147,  .615);
 const QPointF YUV_G(-.289, -.515);
@@ -67,11 +64,10 @@ Vectorscope::Vectorscope(QWidget *parent) :
     ui->sliderGain->setMinimum(0);
     ui->sliderGain->setMaximum(40);
 
-    bool b = true;
-    b &= connect(ui->backgroundMode, SIGNAL(currentIndexChanged(int)), this, SLOT(slotBackgroundChanged()));
-    b &= connect(ui->sliderGain, SIGNAL(valueChanged(int)), this, SLOT(slotGainChanged(int)));
-    b &= connect(ui->paintMode, SIGNAL(currentIndexChanged(int)), this, SLOT(forceUpdateScope()));
-    b &= connect(this, SIGNAL(signalMousePositionChanged()), this, SLOT(forceUpdateHUD()));
+    connect(ui->backgroundMode, SIGNAL(currentIndexChanged(int)), this, SLOT(slotBackgroundChanged()));
+    connect(ui->sliderGain, SIGNAL(valueChanged(int)), this, SLOT(slotGainChanged(int)));
+    connect(ui->paintMode, SIGNAL(currentIndexChanged(int)), this, SLOT(forceUpdateScope()));
+    connect(this, SIGNAL(signalMousePositionChanged()), this, SLOT(forceUpdateHUD()));
     ui->sliderGain->setValue(0);
 
 
@@ -81,24 +77,24 @@ Vectorscope::Vectorscope(QWidget *parent) :
 
     m_aExportBackground = new QAction(i18n("Export background"), this);
     m_menu->addAction(m_aExportBackground);
-    b &= connect(m_aExportBackground, SIGNAL(triggered()), this, SLOT(slotExportBackground()));
+    connect(m_aExportBackground, SIGNAL(triggered()), this, SLOT(slotExportBackground()));
 
     m_menu->addSeparator()->setText(i18n("Drawing options"));
 
     m_a75PBox = new QAction(i18n("75% box"), this);
     m_a75PBox->setCheckable(true);
     m_menu->addAction(m_a75PBox);
-    b &= connect(m_a75PBox, SIGNAL(changed()), this, SLOT(forceUpdateBackground()));
+    connect(m_a75PBox, SIGNAL(changed()), this, SLOT(forceUpdateBackground()));
 
     m_aAxisEnabled = new QAction(i18n("Draw axis"), this);
     m_aAxisEnabled->setCheckable(true);
     m_menu->addAction(m_aAxisEnabled);
-    b &= connect(m_aAxisEnabled, SIGNAL(changed()), this, SLOT(forceUpdateBackground()));
+    connect(m_aAxisEnabled, SIGNAL(changed()), this, SLOT(forceUpdateBackground()));
 
     m_aIQLines = new QAction(i18n("Draw I/Q lines"), this);
     m_aIQLines->setCheckable(true);
     m_menu->addAction(m_aIQLines);
-    b &= connect(m_aIQLines, SIGNAL(changed()), this, SLOT(forceUpdateBackground()));
+    connect(m_aIQLines, SIGNAL(changed()), this, SLOT(forceUpdateBackground()));
 
     m_menu->addSeparator()->setText(i18n("Color Space"));
     m_aColorSpace_YPbPr = new QAction(i18n("YPbPr"), this);
@@ -110,10 +106,8 @@ Vectorscope::Vectorscope(QWidget *parent) :
     m_agColorSpace->addAction(m_aColorSpace_YUV);
     m_menu->addAction(m_aColorSpace_YPbPr);
     m_menu->addAction(m_aColorSpace_YUV);
-    b &= connect(m_aColorSpace_YPbPr, SIGNAL(toggled(bool)), this, SLOT(slotColorSpaceChanged()));
-    b &= connect(m_aColorSpace_YUV, SIGNAL(toggled(bool)), this, SLOT(slotColorSpaceChanged()));
-
-    Q_ASSERT(b);
+    connect(m_aColorSpace_YPbPr, SIGNAL(toggled(bool)), this, SLOT(slotColorSpaceChanged()));
+    connect(m_aColorSpace_YUV, SIGNAL(toggled(bool)), this, SLOT(slotColorSpaceChanged()));
 
     // To make the 1.0x text show
     slotGainChanged(ui->sliderGain->value());
@@ -138,7 +132,10 @@ Vectorscope::~Vectorscope()
     delete ui;
 }
 
-QString Vectorscope::widgetName() const { return QString("Vectorscope"); }
+QString Vectorscope::widgetName() const
+{
+    return QLatin1String("Vectorscope");
+}
 
 void Vectorscope::readConfig()
 {
@@ -215,6 +212,7 @@ QImage Vectorscope::renderHUD(uint)
 
     QImage hud;
     QLocale locale;
+    locale.setNumberOptions(QLocale::OmitGroupSeparator);
     if (m_mouseWithinWidget) {
         // Mouse moved: Draw a circle over the scope
 
@@ -259,7 +257,7 @@ QImage Vectorscope::renderHUD(uint)
     return hud;
 }
 
-QImage Vectorscope::renderGfxScope(uint accelerationFactor, const QImage qimage)
+QImage Vectorscope::renderGfxScope(uint accelerationFactor, const QImage &qimage)
 {
     QTime start = QTime::currentTime();
     QImage scope;
@@ -505,6 +503,7 @@ QImage Vectorscope::renderBackground(uint)
 void Vectorscope::slotGainChanged(int newval)
 {
     QLocale locale;
+    locale.setNumberOptions(QLocale::OmitGroupSeparator);
     m_gain = 1 + (float)newval/10;
     ui->lblGain->setText(locale.toString(m_gain, 'f', 1) + 'x');
     forceUpdateScope();
@@ -559,3 +558,5 @@ void Vectorscope::slotColorSpaceChanged()
     }
     forceUpdate();
 }
+
+#include "vectorscope.moc"
