@@ -24,7 +24,7 @@
 #include <KColorScheme>
 #include <QWidget>
 
-#include "monitormanager.h"
+#include "monitor/monitormanager.h"
 
 
 class SmallRuler : public QWidget
@@ -33,25 +33,24 @@ class SmallRuler : public QWidget
 
 public:
     explicit SmallRuler(Monitor *manager, Render *render, QWidget *parent = 0);
-    virtual void mousePressEvent(QMouseEvent * event);
-    virtual void mouseMoveEvent(QMouseEvent * event);
-    virtual void mouseReleaseEvent(QMouseEvent * event);
     void adjustScale(int maximum);
     void setZone(int start, int end);
     void setZoneStart();
     void setZoneEnd();
-    QPoint zone();
-    void setMarkers(QList < CommentedTime > list);
+    QPoint zone() const;
+    void setMarkers(const QList < CommentedTime >& list);
     void updatePalette();
     void refreshRuler();
 
 protected:
-    virtual void paintEvent(QPaintEvent *e);
-    virtual void resizeEvent(QResizeEvent *);
-    virtual void leaveEvent(QEvent * event);
+    void paintEvent(QPaintEvent *e);
+    void resizeEvent(QResizeEvent *);
+    void leaveEvent(QEvent * event);
+    void mousePressEvent(QMouseEvent * event);
+    void mouseMoveEvent(QMouseEvent * event);
+    void mouseReleaseEvent(QMouseEvent * event);
 
 private:
-    int m_cursorPosition;
     int m_cursorFramePosition;
     double m_scale;
     int m_medium;
